.. _tests:

Tests
=====

.. image:: https://github.com/adxorg/astrodynx/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/adxorg/astrodynx/actions/workflows/ci.yml
.. image:: https://codecov.io/gh/adxorg/astrodynx/graph/badge.svg?token=azxgWzPIIU
   :target: https://codecov.io/gh/adxorg/astrodynx


All tests are available on `GitHub <https://github.com/adxorg/astrodynx/tree/main/tests>`_.


Coverage reports are available on `Codecov <https://codecov.io/gh/adxorg/astrodynx>`_.
